pymop - Multi-Objective Optimization Problems
==================================

This framework provides a collection of test problems in Python. The main features are:

- Most important multi-objective test function is one place
- Vectorized evaluation by using numpy matrices
- Easily new problems can be created using custom classes or functions

At https://www.egr.msu.edu/coinlab/blankjul/pymop/ you can find a detailed documentation and
information about the framework.


Problems
==================================

In this package single- as well as multi-objective test problems are
included:


-  Single-Objective:

   -  Ackley
   -  BNH
   -  Griewank
   -  Knapsack
   -  Schwefel
   -  Sphere
   -  Zakharov

-  Multi-Objective:

   -  ZDT 1-6 
   -  DTLZ 1-7 
   -  WFG 1-9 
   -  Carside Impact
   -  BNH
   -  Kursawe
   -  OSY`
   -  TNK
   -  Welded Beam
